==> vtigercrm7.1.0rc.tar.gz: modules/EmailTemplates.php <==
<?php
/*+***********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 *************************************************************************************/
$languageStrings = array(
    'Email Templates' => 'Email Templates',
	'LBL_ADD_RECORD' => 'Add Email Template',
	'SINGLE_EmailTemplates' => 'Email Template',
	'LBL_EMAIL_TEMPLATES'=> 'Email Templates',
	'LBL_EMAIL_TEMPLATE' => 'Email Template',
	
	'LBL_TEMPLATE_NAME' => 'Template name',
	'LBL_DESCRIPTION' => 'Description',
	'LBL_SUBJECT' => 'Subject',
	'LBL_GENERAL_FIELDS' => 'General Fields',
	'LBL_SELECT_FIELD_TYPE' => 'Seleccione Módulo & Field',
	'LBL_MODULE_NAME' => 'Nombre del módulo',
	'LBL_EMAIL_TEMPLATE_DESCRIPTION'=>'Manage templates for E-Mail module',
	'LBL_NO_PERMISSIONS_TO_DELETE_SYSTEM_TEMPLATE' => 'No hay permisos para eliminar plantilla del sistema',
	'LBL_RECORD_ID'                => 'ID de registro'              , 
	
);

$jsLanguageStrings = array(
    'LBL_CUTOMER_LOGIN_DETAILS_TEMPLATE_DELETE_MESSAGE' => 'Usted no será capaz de enviar los datos de acceso Portal de clientes al contacto si elimina el "Cliente Login detalles" de la plantilla. ¿Desea continuar?',
	'JS_REQUIRED_FIELD' => '* Se requiere Mensaje',
);

==> vtigercrm7.5.0.tar.gz: modules/EmailTemplates.php <==
<?php
/*+***********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 *************************************************************************************/
$languageStrings = array(
    'Email Templates' => 'Email Templates',
	'LBL_ADD_RECORD' => 'Add Email Template',
	'SINGLE_EmailTemplates' => 'Email Template',
	'LBL_EMAIL_TEMPLATES'=> 'Email Templates',
	'LBL_EMAIL_TEMPLATE' => 'Email Template',
	
	'LBL_TEMPLATE_NAME' => 'Template name',
	'LBL_DESCRIPTION' => 'Description',
	'LBL_SUBJECT' => 'Subject',
	'LBL_GENERAL_FIELDS' => 'General Fields',
	'LBL_SELECT_FIELD_TYPE' => 'Válassza ki a Modul & Field',
	'LBL_MODULE_NAME' => 'Modul neve',
	'LBL_EMAIL_TEMPLATE_DESCRIPTION'=>'Manage templates for E-Mail module',
	'LBL_NO_PERMISSIONS_TO_DELETE_SYSTEM_TEMPLATE' => 'Nem Engedélyek törölni Rendszer Sablon',
	'LBL_RECORD_ID'                => 'Rekordazonosja'         , 
);

$jsLanguageStrings = array(
    'LBL_CUTOMER_LOGIN_DETAILS_TEMPLATE_DELETE_MESSAGE' => 'Ön nem fogja tudni elküldeni az ügyfél portál bejelentkezési adatait a kapcsolatot, ha törli "Vásárló Belépés Részletek" sablont. Szeretné folytatni?',
	'JS_REQUIRED_FIELD' => '* Message szükséges',
);
